@@ -1,15 +1,11 @@
 
 
-
-
 ag_on.exit <- function(expr = NULL, add = TRUE, after = FALSE) {
 
-  if(!add) {
-    stop
-  }
   env <- parent.frame()
   if(!add &&
-     !requireNamespace("rlang") || !is.null(rlang::eval_bare(quote(sys.on.exit()), env)))
+     !requireNamespace("rlang") ||
+     !is.null(rlang::eval_bare(quote(sys.on.exit()), env)))
     stop("autograph() requires that `add = TRUE` be specified in this `on.exit` call.
     This is because autographing functions that register control dependencies
     like `stopifnot()` use the `on.exit()` mechanism to ensure those control dependencies
@@ -20,12 +16,11 @@ ag_on.exit <- function(expr = NULL, add = TRUE, after = FALSE) {
 }
 
 
-on.exit.elsewhere <- function(expr = NULL, add = TRUE, after = TRUE, envir = parent.frame(2)) {
+on.exit.elsewhere <- function(expr = NULL, add = TRUE, after = TRUE,
+                              envir = parent.frame(2)) {
   if(!requireNamespace("rlang"))
     stop("Package `rlang` is required for tfautograph to capture control dependencies if you are in graph mode and outside a tf.function() context.")
   cl <- as.call(c(quote(base::on.exit), substitute(expr),
                   add = add, after = after))
   rlang::eval_bare(cl, envir)
 }
-
-
